@@ -18,5 +18,5 @@ alfa.rda <- function(xnew, x, ina, a, gam = 1, del = 0) {
   ## del*QDa+(1-del)*LDA
   y <- Compositional::alfa(x, a)$aff  ## apply the alpha-transformation
   ynew <- Compositional::alfa(xnew, a)$aff
-  Compositional::rda(xnew = ynew, x = y, ina = ina, gam = gam, del = del)
+  regda::rda(xnew = ynew, x = y, ina = ina, gam = gam, del = del)
 }
